@@ -5,7 +5,7 @@ import os
 
 
 # ID блокировок postgresql. Должны быть уникальны в пределах проекта
-PG_LOCK_ID = hash('audit_log_lock')
+PG_LOCK_ID = 2710589049657585281
 
 
 #: Игнорируемые таблицы.
