@@ -45,34 +45,40 @@ def configure():
 
 def _set_audit_log_tables():
     """Собирает логируемые таблицы."""
-    from django import VERSION
     from django.apps import apps
 
-    tables = set(model._meta.db_table
-                 for model in apps.get_models()
-                 if getattr(model, 'need_to_log', False))
+    table_names = set(
+        model._meta.db_table
+        for model in apps.get_models()
+        if getattr(model, 'need_to_log', False)
+    )
 
     Table = apps.get_model('audit_log', 'Table')
+    AuditLog = apps.get_model('audit_log', 'AuditLog')
 
     # Создаются таблицы, на которые нужно навесить триггеры
-    if VERSION[:2] >= (2, 22):
-        Table.objects.bulk_create(
-            [Table(name=table, schema='public')
-             for table in tables],
-            ignore_conflicts=True,
-        )
-    else:
-        exists_tables = set(Table.objects.filter(
+    exists_table_names = set(
+        Table.objects.filter(
             schema='public',
-        ).values_list('name', flat=True))
-        tables_to_create = tables.difference(exists_tables)
-        Table.objects.bulk_create(
-            [Table(name=table, schema='public')
-             for table in tables_to_create],
-        )
-    # Все остальные удаляются
-    Table.objects.exclude(
-        name__in=tables,
+        ).values_list('name', flat=True)
+    )
+
+    table_names_for_creating = table_names.difference(exists_table_names)
+    table_names_for_deleting = exists_table_names.difference(table_names)
+
+    Table.objects.bulk_create(
+        objs=[
+            Table(name=table, schema='public')
+            for table in table_names_for_creating
+        ],
+    )
+
+    # В Django 1.11 не устанавливается ON DELETE CASCADE, поэтому подчистим логи заранее
+    AuditLog.objects.filter(table__name__in=table_names_for_deleting).delete()
+
+    # Удаление таблиц, изменение записей которых не должны логироваться
+    Table.objects.filter(
+        name__in=table_names_for_deleting,
     ).delete()
 
 
